# pyPreservica
Python language binding for the Preservica Entity API

https://preservica.com/

This library provides a Python class for working with the Entity API v6.1

https://us.preservica.com/api/entity/documentation.html


The full documentation is available at: https://pypreservica.readthedocs.io/
